% UQOTHESE DOCUMENT CLASS -- Release info is below.
%    for LaTeX version 2e - 11/3/94

%%% ====================================================================
%%%  @LaTeX-class-file{
%%%     author          = "Aymeric Nys",
%%%     filename        = "uqothese.cls",
%%%     version         = "0.2",
%%%     date            = "09 May 2005",
%%%     codetable       = "ISO/8859-1",
%%%     keywords        = "LaTeX, uqothese",
%%%     docstring       = "This file is the main file for the uqothese
%%%                        class, which is intended to meet the requirements
%%%                        for Universit du Qubec en Outaouais master and Phd
%%%                        dissertations.
%%%                        It is a based on the report class
%%%  }
%%% ====================================================================

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{uqothese}[2003/06/09 v0.1 Universit du Qubec en Outaouais Thesis Class]

% Load class report with option from uqothese
% ex: \documentclass[11pt]{uqothese} => \documentclass[11pt]{report}
\LoadClassWithOptions{report}


% Load latin1 for input
\DeclareOption*{\PassOptionsToPackage{latin1}{inputenc}}
\DeclareOption*{\PassOptionsToPackage{T1}{fontenc}}

\DeclareOption{twocolum}{\@twocolumntrue}

\ProcessOptions

\RequirePackage{appendix}
\RequirePackage{graphicx}
\RequirePackage{inputenc}
\RequirePackage{fontenc}
\RequirePackage{ifthen}
\RequirePackage{tabularx}
\RequirePackage{setspace}
\RequirePackage{fancyhdr}


% French Support
\DeclareOption*{\PassOptionsToPackage{french}{babel}}
\ProcessOptions
\RequirePackage{babel}

%  *************************************
%  *          Page size                *
%  *************************************
%
\setlength{\voffset}{-0.3in}
\evensidemargin +1cm
\oddsidemargin +1cm
\topmargin +1.5cm
\textwidth 6.2in
\textheight 8.5in

% vite les veuves et orphelines
\widowpenalty=10000
\clubpenalty=10000
\raggedbottom

%  *************************************
%  *          New command              *
%  *************************************
%


% Which univesity you belong
\newcommand{\@university}{\bf Universit du Qubec en Outaouais}
\newcommand{\university}[1]{\renewcommand{\@university}{#1}}

%  Which department you belong
\newcommand{\@department}{Dpartement d'informatique et d'ingnierie}
\newcommand{\department}[1]{\renewcommand{\@department}{#1}}

% Type of document you write
% matrise => mmoire
% doctorat => thse
\newcommand{\@typeofthese}{mmoire}

% Type of degree attended
\newcommand{\@degree}{matrise}
\newcommand{\degree}[1]{%
  \renewcommand{\@degree}{#1}
  \ifthenelse{\equal{\@degree}{doctorat}}{%
    \renewcommand{\@typeofthese}{thse}
  }{}
}

% The year the degree will be officially conferred
\newcommand{\@degreeyear}{2003}
\newcommand{\degreeyear}[1]{\renewcommand{\@degreeyear}{#1}}

% The month the degree will be officially conferred
\newcommand{\@degreemonth}{Juin}
\newcommand{\degreemonth}[1]{\renewcommand{\@degreemonth}{#1}}

% Field of study
\newcommand{\@field}{SCIENCES ET TECHNOLOGIES DE L'INFORMATION}
\newcommand{\field}[1]{\renewcommand{\@field}{#1}}

% Acceptation date
\newcommand{\@approvaldate}{21 juin 2013}
\newcommand{\approvaldate}[1]{\renewcommand{\@approvaldate}{#1}}

% Grade
\newcommand{\@grade}{matre s science (M.Sc.)}
\newcommand{\grade}[1]{\renewcommand{\@grade}{#1}}

% title of acknowledgement section
\newcommand{\acknowledgename}{Acknowledgments}
\renewcommand{\acknowledgename}{Remerciements}

% title of foreword section
\newcommand{\forewordname}{Avant-propos}

% title for annexes (appendice)
%\newcommand{\annexename}{Appendice}

% title for la list of abreviations
\newcommand{\@siglechaptername}{Liste des abrviations, sigles et acronymes}
\newcommand{\siglechaptername}[1]{\renewcommand{\@siglechaptername}{#1}}

% title for la list of symbols
\newcommand{\@symbolchaptername}{Liste des symboles}
\newcommand{\symbolchaptername}[1]{\renewcommand{\@symbolchaptername}{#1}}

% The number of committee members, which affects both the
% number of lines and the amount of space between lines
% on the approval page.
\newcommand{\@numberofmembers}{3}
\newcommand{\numberofmembers}[1]{\renewcommand{\@numberofmembers}{#1}}

% Name and position of the committe member
\newcommand{\@committeemembera}{NULL}
\newcommand{\committeemembera}[2]{\renewcommand{\@committeemembera}{#1 \dotfill\ #2}}
\newcommand{\@committeememberb}{NULL}
\newcommand{\committeememberb}[2]{\renewcommand{\@committeememberb}{#1 \dotfill\ #2}}
\newcommand{\@committeememberc}{NULL}
\newcommand{\committeememberc}[2]{\renewcommand{\@committeememberc}{#1 \dotfill\ #2}}
\newcommand{\@committeememberd}{NULL}
\newcommand{\committeememberd}[2]{\renewcommand{\@committeememberd}{#1 \dotfill\ #2}}
\newcommand{\@committeemembere}{NULL}
\newcommand{\committeemembere}[2]{\renewcommand{\@committeemembere}{#1 \dotfill\ #2}}


% Chapter numbering
%\renewcommand{\thechapter}{\@Roman\c@chapter}


% style for header and footer.

% Il doit surement avoir y avoir une faon plus simple.
\renewcommand{\chaptermark}[1]{\markright{\chaptername~\thechapter~:~#1}}
\newcommand*{\DH@title}{\rightmark}

\fancypagestyle{plain}{%
  \fancyhf{}
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
}

\newlength{\titleinheader}
\setlength{\titleinheader}{\textwidth}
\addtolength{\titleinheader}{-1cm}

\newcommand*{\ps@dochead}{
  \renewcommand*{\@oddhead}{
    \begin{minipage}{\textwidth}\normalfont\begin{singlespace}
      \begin{tabular*}{\textwidth}[t]{@{}p{\titleinheader}@{\extracolsep{\fill}}r@{}}%
        {\small \DH@title} & \thepage
      \end{tabular*}\vspace{0.5ex}
      \rule{\textwidth}{0.6pt}%
      \end{singlespace}
    \end{minipage}
  }
  \renewcommand*{\@evenhead}{\@oddhead}
  \renewcommand*{\@oddfoot}{}
  \renewcommand*{\@evenfoot}{}
}

%test
%\def\ps@myheadings{%
%    \let\@oddfoot\@empty\let\@evenfoot\@empty
%    \def\@evenhead{\thepage\hfil\slshape\leftmark}%
%    \def\@oddhead{{\slshape\rightmark}\hfil\thepage}%
%    \let\@mkboth\@gobbletwo
%    \let\chaptermark\@gobble
%    \let\sectionmark\@gobble
%}
%test

%  *************************************
%  *          New environment          *
%  *************************************
%

% *************************
% *   Page numbering style
% *************************

% Set page number style for approval page,
% dedication, acknowledgement
\newenvironment{uqopredoc}
  {
  	\renewcommand{\headheight}{14.5pt}
    \pagenumbering{roman}
    \fancypagestyle{plain}
    {%
      \fancyhf{}
    }
    \renewcommand{\headrulewidth}{0pt}
    \renewcommand{\footrulewidth}{0pt}
    \lhead{} \chead{} \rhead{\thepage}
    \lfoot{} \cfoot{} \rfoot{}
    \pagestyle{fancy}
  }
  {\clearpage}

% Set style for the core pages
\newenvironment{uqodoc}{
  \setlength{\headheight}{14.5pt}
  \setlength{\headsep}{3em}%3

  \pagenumbering{arabic}
  \pagestyle{dochead}
  \begin{onehalfspace}
}
{
  \end{onehalfspace}
  \clearpage
}

% Set page number style for annexes, bibliographie
\newenvironment{uqopostdoc}{
  \fancypagestyle{plain}{%
    \fancyhf{}
    \renewcommand{\headrulewidth}{0pt}
    \renewcommand{\footrulewidth}{0pt}
    \lhead{} \chead{} \rhead{}
    \lfoot{} \cfoot{} \rfoot{}
  }
  \fancyhf{}
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
  \lhead{} \chead{} \rhead{\thepage}
  \lfoot{} \cfoot{} \rfoot{}
  \pagestyle{fancy}

  \appendix
}
{
  \clearpage
}


% *************************
% *   Pages styles
% *************************

% *************************
% *   Title page
% *************************
% \maketitle overload
\renewcommand{\maketitle}{
  \enlargethispage*{1000pt}
\begin{titlepage}%
    \thispagestyle{empty}
    \setcounter{page}{0}
     \vspace*{\fill}%\null\vfil

    \begin{center}
%      \vspace{-2cm}

\parbox[t][2cm][t]{\linewidth}{
  \begin{center}
    \setlength{\baselineskip}{24pt}
    \MakeUppercase{\@university}
  \end{center}
}%
      \vspace{1cm}

\addtolength{\linewidth}{-.5cm}
\parbox[t][3cm][c]{\linewidth}{
  \begin{center}
      \setlength{\baselineskip}{24pt}
      \MakeUppercase{\@title}
  \end{center}
}%
\addtolength{\linewidth}{.5cm}

      \vspace{2cm}

\parbox[t]{\linewidth}{
  \begin{center}
      \setlength{\baselineskip}{20pt}
      \MakeUppercase{\@typeofthese} \par

      \ifthenelse{\equal{\@degree}{matrise}}{%
        PRSENT \par
      }{}
       \ifthenelse{\equal{\@degree}{doctorat}}{%
        PRSENTE \par
       }{}

        COMME EXIGENCE PARTIELLE \par

       \ifthenelse{\equal{\@degree}{matrise}}{%
        DE LA}{}%
       \ifthenelse{\equal{\@degree}{doctorat}}{%
        DU}{}\ %
       \MakeUppercase{\@degree} EN \MakeUppercase{\@field}
  \end{center}
}%
      \vspace{3cm}

    PAR \par
    \vspace{0.5cm}
    \MakeUppercase{\@author} \par
    \vspace{2cm}
    \MakeUppercase{\@degreemonth} \@degreeyear

 \end{center}
 \vspace*{\fill}
 \pagestyle{empty}
\end{titlepage}
}

% *************************
% *   Approval page
% *************************
% This page can be called or not.
\newcommand{\approvalpage}
{
  \enlargethispage*{1000pt}
  \pagestyle{empty}
  \begin{titlepage}%
    \setcounter{page}{0}
    \null\vfil

%    \begin{center}
%
%      \parbox[t][2cm][t]{\linewidth}{
%        \begin{center}
%          \setlength{\baselineskip}{24pt}
%          \MakeUppercase{\@university} \par
%          \@department
%        \end{center}
%      }%
%      \vspace{2cm}

%      \ifthenelse{\equal{\@degree}{matrise}}{%
%        Ce }{}%
%      \ifthenelse{\equal{\@degree}{doctorat}}{
%        Cette }{}%
%      \@typeofthese\
%      \ifthenelse{\equal{\@degree}{matrise}}{%
%        intitul~: \par
%        }{}
%      \ifthenelse{\equal{\@degree}{doctorat}}{%
%        intitule~: \par
%      }{}
%
%      \addtolength{\linewidth}{-.5cm}
%      \parbox[t][3cm][c]{\linewidth}{
%        \begin{center}
%          \setlength{\baselineskip}{24pt}
%          \MakeUppercase{\@title}
%        \end{center}
%      }%
%      \addtolength{\linewidth}{.5cm}
%
%      \vspace{2cm}
%      \ifthenelse{\equal{\@degree}{matrise}}{%
%        prsent par \par
%      }{}
%      \ifthenelse{\equal{\@degree}{doctorat}}{%
%        prsente par \par
%      }{}
%      \@author

%      \vspace{.25cm}
%      pour l'obtention du grade de
%      \@grade \par

      \vspace{1cm}
      Ce mmoire a t valu par un jury compos des personnes suivantes~: \par

      \addtolength{\linewidth}{-3cm}
      \parbox[t][4cm][t]{\linewidth}{
        \begin{center}
          \setlength{\baselineskip}{20pt}
          \vspace{0.5cm}
          \@committeemembera \par
          \vspace{0.5cm}
          \@committeememberb \par
          \vspace{0.5cm}
          \@committeememberc \par
          \vspace{0.5cm}
          \ifthenelse{\@numberofmembers > 3}{\@committeememberd \par}{}
          \vspace{0.5cm}
          \ifthenelse{\@numberofmembers > 4}{\@committeemembere \par}{}
        \end{center}
      }
      \addtolength{\linewidth}{3cm}

      \vspace{2cm}
      \ifthenelse{\equal{\@degree}{matrise}}{%
        Mmoire accept\ }{}%
      \ifthenelse{\equal{\@degree}{doctorat}}{%
        Thse accepte\ }{}%
      le~: \@approvaldate

    %\end{center}
  \end{titlepage}
  \clearpage
}

% ****************************************
% * Dedication environment
% ****************************************
\newenvironment{uqodedication}{
  \begin{titlepage}
    \thispagestyle{empty}
    \null\vfill
    \setlength{\baselineskip}{20pt}
    \setlength{\parskip}{2cm}
    \begin{center}
      \itshape
}
{
    \end{center}
    \null\vfill
  \end{titlepage}
  \clearpage
}


% ****************************************
% * Abstract definition
% ****************************************
% generic abstract
\newcommand{\@uqoabstract}[2]{
  \chapter*{#1}
  \begin{onehalfspace}
    #2
  \end{onehalfspace}
  \clearpage
}

\newcommand{\abstractnamefr}{Rsum}
\newcommand{\abstractnameen}{Abstract}

\newcommand{\uqoabstract}[2]{
  \newpage \addcontentsline{toc}{chapter}{\abstractnamefr}
  \@uqoabstract{\abstractnamefr}{#1}
  \newpage
  \@uqoabstract{\abstractnameen}{#2}
}

% ****************************************
% * Insert all of the lists
% ****************************************
\newcommand{\uqolists}{
  \renewcommand{\contentsname}{Table des matires}%
  \renewcommand{\listfigurename}{Liste des figures}%
  \renewcommand{\listtablename}{Liste des tableaux}%
  \begin{onehalfspace}
    \newpage \tableofcontents
    \newpage \addcontentsline{toc}{chapter}{\listfigurename} \listoffigures
    \newpage \addcontentsline{toc}{chapter}{\listtablename}  \listoftables
  \end{onehalfspace}
  \clearpage
}

%%%
% In case there is no figure or no table, uqolists will write a page with
% just a title
% So use \uqotoc then \uqofiglist if you only have figures
% OR \uqotoc then \uqotablist if you only have tabs
%

\newcommand{\uqotoc}{
  \renewcommand{\contentsname}{Table des matires}%
  \begin{onehalfspace}
    \newpage \tableofcontents
  \end{onehalfspace}
  \clearpage
}

\newcommand{\uqofiglist}{
  \renewcommand{\listfigurename}{Liste des figures}%
  \begin{onehalfspace}
    \newpage \addcontentsline{toc}{chapter}{\listfigurename} \listoffigures
  \end{onehalfspace}
  \clearpage
}

\newcommand{\uqotablist}{
  \renewcommand{\listtablename}{Liste des tableaux}%
  \begin{onehalfspace}
    \newpage \addcontentsline{toc}{chapter}{\listtablename}  \listoftables
  \end{onehalfspace}
  \clearpage
}

\newcommand{\uqosiglelist}[1]{
  \newpage \addcontentsline{toc}{chapter}{\@siglechaptername}
  \chapter*{\@siglechaptername}
  \begin{onehalfspace}
    #1
  \end{onehalfspace}
  \clearpage
}

\newcommand{\uqosymbollist}[1]{
  \newpage \addcontentsline{toc}{chapter}{\@symbolchaptername}
  \chapter*{\@symbolchaptername}
  \begin{onehalfspace}
    #1
  \end{onehalfspace}
  \clearpage
}


% ****************************************
% * Acknowledgment environment
% ****************************************
% use \section* in this environement
\newenvironment{uqoacknowledge}{
  \fancypagestyle{plain}{%
    \fancyhf{}
    \renewcommand{\headrulewidth}{0pt}
    \renewcommand{\footrulewidth}{0pt}
  }
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
  \lhead{} \chead{} \rhead{\thepage}
  \lfoot{} \cfoot{} \rfoot{}

  \chapter*{\acknowledgename}
  \addcontentsline{toc}{chapter}{\acknowledgename}
  \begin{onehalfspace}
}
{
  \end{onehalfspace}
  \clearpage
}

% ****************************************
% * Foreword environment
% ****************************************
% use \section* in this environement
\newenvironment{uqoforeword}
{
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
  \lhead{} \chead{} \rhead{\thepage}
  \lfoot{} \cfoot{} \rfoot{}
  \pagestyle{fancy}

  \fancypagestyle{plain}{%
    \fancyhf{}
    \renewcommand{\headrulewidth}{0pt}
    \renewcommand{\footrulewidth}{0pt}
  }

  \chapter*{\forewordname}
  \addcontentsline{toc}{chapter}{\forewordname}
  \begin{onehalfspace}
}
{
  \end{onehalfspace}
  \clearpage
}


% ****************************************
% * bibliography command
% ****************************************
\newcommand{\uqobibliography}[1]{
  \addcontentsline{toc}{chapter}{\bibname}
  \begin{onehalfspace}
    \bibliographystyle{acm}
    \bibliography{#1}
  \end{onehalfspace}
  \clearpage
}
